pub enum BufferType {
StorageBuffer {
output: bool,
read_only: bool,
},
UniformBuffer,
}Expand description
Specifies buffer type.
Variants
StorageBuffer
A storage buffer. Usually used for holding large data types like vectors. Storage buffers are also the only buffer type that can be mutable.
Fields
UniformBuffer
A uniform buffer. Usually used for holding read-only data like constant parameters.